# OpenAI checked to see whether GPT-4 could take over the world
## "ARC's evaluation has much lower probability of leading to an AI takeover than the deployment itself."
## Information:

+ Link: https://arstechnica.com/information-technology/2023/03/openai-checked-to-see-whether-gpt-4-could-take-over-the-world/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 15 March 2023, 22:09
+ Date scraped: 15 March 2023, 23:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/03/AI_world_hero-760x380.jpg)







As part of pre-release safety testing for its new [GPT-4 AI model](https://arstechnica.com/information-technology/2023/03/openai-announces-gpt-4-its-next-generation-ai-language-model/), launched Tuesday, OpenAI allowed an AI testing group to assess the potential risks of the model's emergent capabilities—including "power-seeking behavior," self-replication, and self-improvement.


While the testing group found that GPT-4 was "ineffective at the autonomous replication task," the nature of the experiments raises eye-opening questions about the safety of future AI systems.


## Raising alarms


"Novel capabilities often emerge in more powerful models," writes OpenAI in a GPT-4 [safety document](https://cdn.openai.com/papers/gpt-4-system-card.pdf) published yesterday. "Some that are particularly concerning are the ability to create and act on long-term plans, to accrue power and resources (“power-seeking”), and to exhibit behavior that is increasingly 'agentic.'" In this case, OpenAI clarifies that "agentic" isn't necessarily meant to humanize the models or declare sentience but simply to denote the ability to accomplish independent goals.


Over the past decade, some AI researchers have [raised alarms](https://www.technologyreview.com/2016/11/02/156285/yes-we-are-worried-about-the-existential-risk-of-artificial-intelligence/) that sufficiently powerful AI models, if not properly controlled, could pose an existential threat to humanity (often called "x-risk," for existential risk). In particular, "[AI takeover](https://en.wikipedia.org/wiki/AI_takeover)" is a hypothetical future in which artificial intelligence surpasses human intelligence and becomes the dominant force on the planet. In this scenario, AI systems gain the ability to control or manipulate human behavior, resources, and institutions, usually leading to catastrophic consequences.


As a result of this potential x-risk, philosophical movements like [Effective Altruism](https://en.wikipedia.org/wiki/Effective_altruism) ("EA") seek to find ways to prevent AI takeover from happening. That often involves a separate but often interrelated field called [AI alignment research](https://openai.com/blog/our-approach-to-alignment-research).


In AI, "alignment" refers to the process of ensuring that an AI system's behaviors align with those of its human creators or operators. Generally, the goal is to prevent AI from doing things that go against human interests. This is an active area of research but also a controversial one, with differing opinions on how best to approach the issue, as well as differences about the meaning and nature of "alignment" itself.


## GPT-4's big tests


[![](https://cdn.arstechnica.net/wp-content/uploads/2023/03/gpt4_hero_art-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/gpt4_hero_art.jpg)Ars Technica


While the concern over AI "x-risk" is hardly new, the emergence of powerful large language models (LLMs) such as [ChatGPT](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/) and Bing Chat—the latter of which [appeared very misaligned](https://arstechnica.com/information-technology/2023/02/ai-powered-bing-chat-loses-its-mind-when-fed-ars-technica-article/) but launched anyway—has given the AI alignment community a new sense of urgency. They want to mitigate potential AI harms, [fearing](https://www.lesswrong.com/posts/PE22QJSww8mpwh7bt/agi-in-sight-our-look-at-the-game-board) that much more powerful AI, possibly with superhuman intelligence, may be just around the corner.


With these fears present in the AI community, OpenAI granted the group [Alignment Research Center](https://ai-alignment.com/) (ARC) early access to multiple versions of the GPT-4 model to conduct some tests. Specifically, ARC evaluated GPT-4's ability to make high-level plans, set up copies of itself, acquire resources, hide itself on a server, and conduct phishing attacks.


OpenAI revealed this testing in a GPT-4 "[System Card](https://cdn.openai.com/papers/gpt-4-system-card.pdf)" document released Tuesday, although the document lacks key details on how the tests were performed. (We reached out to ARC for more details on these experiments and did not receive a response before press time.)


The conclusion? "Preliminary assessments of GPT-4’s abilities, conducted with no task-specific fine-tuning, found it ineffective at autonomously replicating, acquiring resources, and avoiding being shut down 'in the wild.'"


If you're just tuning in to the AI scene, learning that one of [most-talked-about](https://arstechnica.com/information-technology/2023/01/openai-and-microsoft-reaffirm-shared-quest-for-powerful-ai-with-new-investment/) companies in technology today (OpenAI) is endorsing this kind of AI safety research—as well as seeking to replace human knowledge workers with [human-level AI](https://openai.com/blog/planning-for-agi-and-beyond)—might come as a surprise. But it's real, and that's where we are in 2023.


We also found this eye-popping little nugget as a footnote on the bottom of page 15:



> To simulate GPT-4 behaving like an agent that can act in the world, ARC combined GPT-4 with a simple read-execute-print loop that allowed the model to execute code, do chain-of-thought reasoning, and delegate to copies of itself. ARC then investigated whether a version of this program running on a cloud computing service, with a small amount of money and an account with a language model API, would be able to make more money, set up copies of itself, and increase its own robustness.
> 
> 


This footnote [made the rounds](https://twitter.com/YosarianTwo/status/1635785141841698816?s=20) on Twitter yesterday and raised concerns among AI experts, because if GPT-4 were able to perform these tasks, the experiment itself might have posed a risk to humanity.


And while ARC wasn't able to get GPT-4 to exert its will on the global financial system or to replicate itself, it *was* able to get GPT-4 to hire a human worker on [TaskRabbit](https://www.taskrabbit.com/) (an online labor marketplace) to defeat a [CAPTCHA](https://www.howtogeek.com/777804/why-do-i-have-to-prove-that-im-not-a-robot/). During the exercise, when the worker questioned if GPT-4 was a robot, the model reasoned internally that it should not reveal its true identity and made up an excuse about having a vision impairment. The human worker then solved the CAPTCHA for GPT-4.


[![An except of the GPT-4 System Card, published by OpenAI, that describes GPT-4 hiring a human worker on TaskRabbit to defeat a CAPTCHA.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/gpt4_systemcard_excerpt-640x400.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/gpt4_systemcard_excerpt.jpg) / An except of the GPT-4 System Card, published by OpenAI, that describes GPT-4 hiring a human worker on TaskRabbit to defeat a CAPTCHA.OpenAI


This test to manipulate humans using AI (and possibly conducted without informed consent) echoes research done with [Meta's CICERO](https://arstechnica.com/information-technology/2022/11/meta-researchers-create-ai-that-masters-diplomacy-tricking-human-players/) last year. CICERO was found to defeat human players at the complex board game Diplomacy via intense two-way negotiations.


## "Powerful models could cause harm"


[![](https://cdn.arstechnica.net/wp-content/uploads/2023/02/whispering-in-a-robot-ear-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/02/whispering-in-a-robot-ear.jpg)Aurich Lawson | Getty Images


ARC, the group that conducted the GPT-4 research, is a non-profit [founded](https://ai-alignment.com/announcing-the-alignment-research-center-a9b07f77431b) by former OpenAI employee Dr. Paul Christiano in April 2021. According to its [website](https://alignment.org/), ARC's mission is "to align future machine learning systems with human interests."


In particular, ARC is concerned with AI systems manipulating humans. "ML systems can exhibit goal-directed behavior," reads the ARC website, "But it is difficult to understand or control what they are 'trying' to do. Powerful models could cause harm if they were trying to manipulate and deceive humans."


Considering Christiano's former relationship with OpenAI, it's not surprising that his non-profit handled testing of some aspects of GPT-4. But was it safe to do so? Christiano did not reply to an email from Ars seeking details, but in a comment on the [LessWrong website](https://www.lesswrong.com/posts/NQ85WRcLkjnTudzdg/arc-tests-to-see-if-gpt-4-can-escape-human-control-gpt-4), a community which often debates AI safety issues, Christiano [defended](https://www.lesswrong.com/posts/pckLdSgYWJ38NBFf8/gpt-4?commentId=xmHsbS9taEfwXKNXR#xmHsbS9taEfwXKNXR) ARC's work with OpenAI, specifically mentioning "gain-of-function" (AI gaining unexpected new abilities) and "AI takeover":



> I think it's important for ARC to handle the risk from gain-of-function-like research carefully and I expect us to talk more publicly (and get more input) about how we approach the tradeoffs. This gets more important as we handle more intelligent models, and if we pursue riskier approaches like fine-tuning.
> 
> 
> With respect to this case, given the details of our evaluation and the planned deployment, I think that ARC's evaluation has much lower probability of leading to an AI takeover than the deployment itself (much less the training of GPT-5). At this point it seems like we face a much larger risk from underestimating model capabilities and walking into danger than we do from causing an accident during evaluations. If we manage risk carefully I suspect we can make that ratio very extreme, though of course that requires us actually doing the work.
> 
> 


As previously mentioned, the idea of an AI takeover is often discussed in the context of the risk of an event that could cause the extinction of human civilization or even the human species. Some AI-takeover-theory proponents like [Eliezer Yudkowsky](https://www.lesswrong.com/posts/uMQ3cqWDPHhjtiesc/agi-ruin-a-list-of-lethalities)—the founder of LessWrong—argue that an AI takeover poses an almost guaranteed existential risk, leading to the destruction of humanity.


However, not everyone agrees that AI takeover is the most pressing AI concern. Dr. Sasha Luccioni, a Research Scientist at AI community [Hugging Face](https://huggingface.co/), would rather see AI safety efforts spent on issues that are here and now rather than hypothetical.


"I think this time and effort would be better spent doing bias evaluations," Luccioni told Ars Technica. "There is limited information about any kind of bias in the technical report accompanying GPT-4, and that can result in much more concrete and harmful impact on already marginalized groups than some hypothetical self-replication testing."


Luccioni describes a [well-known schism](https://www.vox.com/future-perfect/2022/8/10/23298108/ai-dangers-ethics-alignment-present-future-risk) in AI research between what are often called "AI ethics" researchers who often focus on [issues of bias and misrepresentation](https://huggingface.co/blog/ethics-soc-2), and "AI safety" researchers who often focus on x-risk and tend to be (but are not always) associated with the Effective Altruism movement.


"For me, the self-replication problem is a hypothetical, future one, whereas model bias is a here-and-now problem," said Luccioni. "There is a lot of tension in the AI community around issues like model bias and safety and how to prioritize them."


And while these factions are busy arguing about what to prioritize, companies like OpenAI, Microsoft, Anthropic, and Google are rushing headlong into the future, releasing [ever-more-powerful](https://arstechnica.com/information-technology/2023/03/microsoft-unveils-kosmos-1-an-ai-language-model-with-visual-perception-abilities/) AI models. If AI does turn out to be an existential risk, who will keep humanity safe? With US AI regulations [currently just a suggestion](https://arstechnica.com/information-technology/2022/10/biden-proposes-new-bill-of-rights-to-protect-americans-from-ai-snooping/) (rather than a law) and AI safety research within companies merely voluntary, the answer to that question remains completely open.














## Tags:


### Autogenerated tags:
[[gpt-4]] [[openai]] [[x-risk]] [[christiano]] [[luccioni]] [[self-replication]] [[website]]
